# Changelog

## [0.5.0] - 2022-06-23

### Changed

- by default ``__`` delimiter will be used
- prefix, delimiter, locations have default values

### Removed

- ``config.get_var`` method removed. All variables 
	have to be declared in sections

### Added

- changelog.md file
